/*
 * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "otbQtApplication.h"
#include <QObject>
#include <iostream>
namespace otb
{
namespace Wrapper
{
QtApplication::QtApplication(int& argcc, char** argvv) : QApplication(argcc, argvv)
{
}

bool QtApplication::notify(QObject* object, QEvent* ev)
{
  try
  {
    return QApplication::notify(object, ev);
  }
  catch (std::exception& ex)
  {
    QString message = QString("<center><font color=\"#FF0000\">");
    message.append(ex.what());
    message.append("</font></center>");
    Q_EMIT UnhandledException(message);
  }
  return false;
}

} // end of namespace Wrapper
} // end of namespace otb
